@@ -7,7 +7,7 @@ import pandas as pd
 import numpy as np
 
 import model
-import view
+import View
 import spyre
 
 import cherrypy
@@ -55,13 +55,13 @@ class Root(object):
 		self.templateVars['custom_js'] = custom_js
 		self.templateVars['custom_css'] = custom_css
 
-		v = view.View()
+		v = View.View()
 		self.templateVars['js'] = v.getJS()
 		self.templateVars['css'] = v.getCSS()
 
 	@cherrypy.expose
 	def index(self):
-		v = view.View()
+		v = View.View()
 		template = jinja2.Template(v.getHTML())
 		return template.render( self.templateVars )
 
@@ -119,7 +119,7 @@ class Root(object):
 
 	@cherrypy.expose
 	def spinning_wheel(self, **args):
-		v = view.View()
+		v = View.View()
 		buffer = v.getSpinningWheel()
 		cherrypy.response.headers['Content-Type'] = 'image/gif'
 		return buffer.getvalue()
